Settings

Struct Settings 

pub struct Settings {
Show 24 fields pub archives: Option<Vec<RepoPath>>, pub cache_timeout: Option<isize>, pub install_path: Option<IPathObject>, pub read_only_installation_paths: Option<Vec<IPathObject>>, pub cfg_version: Option<isize>, pub gui_bounds: Option<Rectangle>, pub gui_maximized: Option<bool>, pub powershell_path: Option<PathBuf>, pub temp_directory: Option<PathBuf>, pub multi_user: Option<bool>, pub projects_default: Option<String>, pub enable_remote_manifests: Option<bool>, pub manifest_repos: Option<Vec<IPathObject>>, pub projects: Option<Vec<IPathObject>>, pub manifests: Option<Vec<IPathObject>>, pub key_store: Option<Vec<IPathObject>>, pub ignore_legacy_platform_repo_deprecation: Option<bool>, pub proxy_settings_to_use: Option<ProxySettingTypes>, pub https_proxy: Option<String>, pub http_proxy: Option<String>, pub no_proxy: Option<String>, pub authentication_config: Option<String>, pub logfile: Option<String>, pub prefer_package_type: Option<InstallationPreference>,
}
V3 ISPM configuration, all fields are optional so older configs that we support should also work without an issue

Fields

archives: Option<Vec<RepoPath>>

Package repositories that ISPM can install from. Managed by the ispm config package-repos command.

cache_timeout: Option<isize>

The timeout of the cache

install_path: Option<IPathObject>

Installation path. Managed by the ispm config install-dir command.

read_only_installation_paths: Option<Vec<IPathObject>>

Installation paths that are set as read-only. Managed by the ispm config ro-install-paths command.

cfg_version: Option<isize>

The configuration version number

gui_bounds: Option<Rectangle>

Last saved bounds of the ISPM GUI

gui_maximized: Option<bool>

Whether the GUI was maximized

powershell_path: Option<PathBuf>

The path to the powershell executable

temp_directory: Option<PathBuf>

The temporary directory used by ISPM. Managed by the ispm config temp-dir command.

multi_user: Option<bool>

Whether this is a multi-user installation

projects_default: Option<String>

The default projects

enable_remote_manifests: Option<bool>

Whether remtoe manifests are enabled

manifest_repos: Option<Vec<IPathObject>>

Platform repositories that ISPM can install from. Managed by the ispm config platform-repos command.

projects: Option<Vec<IPathObject>>

A list of registered projects

manifests: Option<Vec<IPathObject>>

A list of manifests

key_store: Option<Vec<IPathObject>>

Files that store decryption keys for legacy package installation. Managed by the ispm config decryption-key-files command.

ignore_legacy_platform_repo_deprecation: Option<bool>

Whether to ignore deprecation warnings for legacy platforms

proxy_settings_to_use: Option<ProxySettingTypes>

Proxy settings that should be used. Managed by the ispm config proxy (--dont-use|--use-env) command and flags.

https_proxy: Option<String>

Proxy settings that should be used for HTTPS. Managed by the ispm config proxy --https command and flags.

http_proxy: Option<String>

Proxy settings that should be used for HTTPS. Managed by the ispm config proxy command.

no_proxy: Option<String>

URL/IP list (comma-delimited) of resources that should not use a proxy for access.

authentication_config: Option<String>

The path to the SIMICS authentication file. Not used for public release. Managed by the ispm config auth-file command.

logfile: Option<String>

The current logfile

prefer_package_type: Option<InstallationPreference>

The package type that is favored

Implementations

Source

impl Settings

pub fn builder() -> SettingsBuilder<((), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), (), ())>

Create a builder for building Settings. On the builder, call .archives(...)(optional), .cache_timeout(...)(optional), .install_path(...)(optional), .read_only_installation_paths(...)(optional), .cfg_version(...)(optional), .gui_bounds(...)(optional), .gui_maximized(...)(optional), .powershell_path(...)(optional), .temp_directory(...)(optional), .multi_user(...)(optional), .projects_default(...)(optional), .enable_remote_manifests(...)(optional), .manifest_repos(...)(optional), .projects(...)(optional), .manifests(...)(optional), .key_store(...)(optional), .ignore_legacy_platform_repo_deprecation(...)(optional), .proxy_settings_to_use(...)(optional), .https_proxy(...)(optional), .http_proxy(...)(optional), .no_proxy(...)(optional), .authentication_config(...)(optional), .logfile(...)(optional), .prefer_package_type(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of Settings.

Source

impl Settings

pub fn get() -> Result<Self>

Get the current settings from the currently set configuration file